.. image:: https://img.shields.io/pypi/v/jaraco.ui.svg
   :target: https://pypi.org/project/jaraco.ui

.. image:: https://img.shields.io/pypi/pyversions/jaraco.ui.svg

.. image:: https://img.shields.io/pypi/dm/jaraco.ui.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.ui/master.svg
   :target: http://travis-ci.org/jaraco/jaraco.ui


License
=======

License is indicated in the project metadata (typically one or more
of the Trove classifiers). For more details, see `this explanation
<https://github.com/jaraco/skeleton/issues/1>`_.

Docs
====

There's `no good mechanism for publishing documentation
<https://github.com/pypa/python-packaging-user-guide/pull/266>`_
easily. If there's a documentation link above, it's probably
stale because PyPI-based documentation is deprecated. This
project may have documentation published at ReadTheDocs, but
probably not. Good luck finding it.
